changeset 38236:ec872cb65bc3

(bdf-directory-list): Use the value relative to installation-directory for MS-Windows as well.
author Eli Zaretskii <eliz@gnu.org>
date Fri, 29 Jun 2001 17:50:27 +0000
parents c6078ee53ddf
children 9b3aa64643fa
files lisp/ps-bdf.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ps-bdf.el	Fri Jun 29 17:50:05 2001 +0000
+++ b/lisp/ps-bdf.el	Fri Jun 29 17:50:27 2001 +0000
@@ -40,15 +40,15 @@
 
 ;;;###autoload
 (defvar bdf-directory-list
-  (if (eq system-type 'ms-dos)
+  (if (memq system-type '(ms-dos windows-nt))
       (list (expand-file-name "fonts/bdf" installation-directory))
     '("/usr/local/share/emacs/fonts/bdf"))
   "*List of directories to search for `BDF' font files.
 The default value is '(\"/usr/local/share/emacs/fonts/bdf\").")
 
-;; MS-DOS users like to move the binary around after it's built, but
-;; the value above is computed at load-up time.
-(and (eq system-type 'ms-dos)
+;; MS-DOS and MS-Windows users like to move the binary around after
+;; it's built, but the value above is computed at load-up time.
+(and (memq system-type '(ms-dos windows-nt))
      (setq bdf-directory-list
 	   (list (expand-file-name "fonts/bdf" installation-directory))))